"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getObjectType = getObjectType;
exports.isAnimation = isAnimation;
exports.isPlatformObject = isPlatformObject;
exports.isWindow = isWindow;
exports.isQuickItem = isQuickItem;
exports.moveChild = moveChild;
exports.findChildIndex = findChildIndex;

function getObjectType(obj) {
  if (!Qt.isQtObject(obj)) {
    return '';
  } // debug name is in the form of QObjectType(memory_address);
  // we need to remove the memory address part


  var debugName = obj.toString();
  return debugName.replace(/\(.+\)/, '');
}

function isAnimation(obj) {
  var isQtObject = Qt.isQtObject(obj);
  var objType = getObjectType(obj);
  var isAnimationType = objType === 'QQuickColorAnimation' || objType === 'QQuickNumberAnimation' || objType === 'QQuickPropertyAnimation' || objType === 'QQuickVector3dAnimation' || objType === 'QQuickRotationAnimation' || objType === 'QQuickAnchorAnimation' || objType === 'QQuickParentAnimation ' || objType === 'QQuickSmoothedAnimation' || objType === 'QQuickSpringAnimation';
  return isQtObject && isAnimationType;
}

function isPlatformObject(obj) {
  var isQtObject = Qt.isQtObject(obj);
  var objType = getObjectType(obj);
  var isPlatformType = objType.indexOf('QQuickPlatform') === 0;
  return isQtObject && isPlatformType;
}

function isWindow(obj) {
  var isQtObject = Qt.isQtObject(obj);
  var objType = getObjectType(obj);
  var isWindowType = objType === 'QQuickWindow' || objType === 'QQuickApplicationWindow' || objType === 'QQuickWindowQmlImpl';
  return isQtObject && isWindowType;
} // TODO: revise this later


function isQuickItem(obj) {
  var isQtObject = Qt.isQtObject(obj);
  var hasChildAtMethod = typeof obj.childAt === 'function';
  var hasParentProp = obj.hasOwnProperty('parent');
  var hasDataProp = obj.hasOwnProperty('data');
  return isQtObject && hasChildAtMethod && hasParentProp && hasDataProp;
}

function moveChild(parentData, fromIndex, toIndex) {
  if (fromIndex < 0 || fromIndex >= parentData.length) {
    throw new Error('Out of range: fromIndex');
  }

  if (toIndex < 0 || toIndex >= parentData.length) {
    throw new Error('Out of range: toIndex');
  }

  var child = parentData[fromIndex];

  if (fromIndex < toIndex) {
    var index = fromIndex;

    while (index < toIndex) {
      parentData[index] = parentData[index + 1];
      index++;
    }

    parentData[toIndex] = child;
  } else {
    var _index = fromIndex;

    while (_index > toIndex) {
      parentData[_index] = parentData[_index - 1];
      _index--;
    }

    parentData[toIndex] = child;
  }

  parentData[toIndex].z = 10;
}

function findChildIndex(parentData, child) {
  for (var index = 0; index < parentData.length; index++) {
    var element = parentData[index];

    if (element === child) {
      return index;
    }
  }

  return -1;
}